"use strict";
/**
 * @fileoverview Sophisticate the SVG files and generate the containing HTML file from the template.
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
// ----------------------------------------------------------------------------
// Requirements
// ----------------------------------------------------------------------------
const chalk_1 = require("chalk");
const Ejs = require("ejs");
const FS = require("fs");
const Path = require("path");
const inline_svg_1 = require("./inline-svg");
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * sophisticateHTML - Sophisticate the SVG files and generate the containing
 *                    HTML file from the template.
 *
 * @param {object} argv parsed command line arguments.
 */
function sophisticateHTML(argv) {
    console.log("Generating HTML files…");
    if (argv.s) {
        const fileName = (typeof argv.s === "string") ? argv.s : "inlined-all";
        const processes = [];
        for (const path of argv._) {
            processes.push(inline_svg_1.processSVG(path, argv.c));
        }
        Promise.all(processes).then((data) => {
            writeHTML(argv, fileName, data);
        });
    }
    else {
        for (const path of argv._) {
            inline_svg_1.processSVG(path, argv.c).then((result) => {
                writeHTML(argv, path, result.data);
            });
        }
    }
}
exports.sophisticateHTML = sophisticateHTML;
/**
 * writeHTML - Sophisticate the SVG files and generate the containing
 *             HTML file from the template.
 *
 * @param {object} argv parsed command line arguments.
 * @param {string} path path to the original SVG file OR basename of the HTML file to write.
 * @param {object|string} svg svg object to write into the HTML template.
 */
function writeHTML(argv, path, svg) {
    const filename = `${argv.o}/${getBasenameWithoutExtension(path)}.html`;
    Ejs.renderFile(argv.t, { svg }, (err, str) => {
        if (err) {
            console.log(`[${chalk_1.default.red("ERROR")}] Couldn't render HTML file - ${err.message}`);
            process.exit(1);
        }
        FS.writeFile(filename, str, (fsErr) => {
            if (fsErr) {
                console.log(`[${chalk_1.default.red("ERROR")}] Couldn't write HTML file - ${fsErr.message}`);
                process.exit(1);
            }
            else {
                console.log(`${chalk_1.default.green("DONE!")} - Output: ${filename}`);
            }
        });
    });
}
/**
 * getBasenameWithoutExtension - Return the basename without extension, from the given path.
 *
 * @param {string} path path to reduce.
 * @return {string} basename without extension
 */
function getBasenameWithoutExtension(path) {
    return Path.basename(path).replace(/\.[^/.]+$/, "");
}
//# sourceMappingURL=html.js.map