"use strict";
/**
 * @fileoverview Sophisticate the SVG files.
 * @author Frédéric Maquin <fred@ephread.com>
 */
Object.defineProperty(exports, "__esModule", { value: true });
// ----------------------------------------------------------------------------
// Requirements
// ----------------------------------------------------------------------------
const chalk_1 = require("chalk");
const FS = require("fs");
const Yaml = require("js-yaml");
const LibXmlJs = require("libxmljs");
// ----------------------------------------------------------------------------
// Public
// ----------------------------------------------------------------------------
/**
 * match - Show element matching XPath described in the configuration file.
 *
 * @param {type} argv parsed command line arguments.
 */
function match(argv) {
    FS.readFile(argv._[0], "utf-8", (err, data) => {
        if (err) {
            console.log(`[${chalk_1.default.red("ERROR")}] Couldn't read SVG file - ${err.message}`);
            process.exit(1);
        }
        console.log(chalk_1.default.bold("\nMatches for each XPath in the config file:\n"));
        const namespace = "http://www.w3.org/2000/svg";
        const config = loadConfig(argv.c);
        const xml = LibXmlJs.parseXml(data);
        for (const transformation of config.sophisticate) {
            const xpath = transformation.xpath;
            const elements = xml.root().find(xpath, namespace);
            const nodes = elements.map((element) => {
                const substitute = element.clone(); // TODO: Update type definition to support
                // Node.line()
                const pathAttribute = substitute.attr("d");
                const styleAttribute = substitute.attr("style");
                if (pathAttribute) {
                    pathAttribute.remove();
                }
                if (styleAttribute) {
                    styleAttribute.remove();
                }
                return `    [${chalk_1.default.blue(`LINE ${substitute.line()}`)}] - ${substitute.toString()}`;
            });
            const section = `${chalk_1.default.bold("[XPATH]")} ${chalk_1.default.underline.green(xpath)} ${chalk_1.default.bold("matches")}:`;
            console.log(`${section}\n${nodes.join("\n")}\n`);
        }
    });
}
exports.match = match;
/**
 * loadConfig - load the configuration file
 *
 * @param  {string} configPath the path to the configuration file
 * @return {object}            the loaded configuration
 */
function loadConfig(configPath) {
    try {
        return Yaml.safeLoad(FS.readFileSync(configPath, "utf8"));
    }
    catch (err) {
        console.log(`[${chalk_1.default.red("ERROR")}] Couldn't load config file - ${err.message}`);
        process.exit(1);
    }
}
//# sourceMappingURL=match.js.map